CreateCustomerTokenRequest class

Constructors

CreateCustomerTokenRequest({String? appId, String? firstName, String? lastName, String? email, String? phoneNumber, String? cardType, String? cardBrand, String? card, Device? device, String? deviceId})
CreateCustomerTokenRequest.fromJson(dynamic json)

Properties

appId String?
getter/setter pair
card String?
getter/setter pair
cardBrand String?
getter/setter pair
cardType String?
getter/setter pair
device Device?
getter/setter pair
deviceId String?
getter/setter pair
email String?
getter/setter pair
firstName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastName String?
getter/setter pair
phoneNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited