CallbackData class

Constructors

CallbackData({bool? isAlreadyToken, String? cardToken, String? onepayTransactionId, String? customerId})
CallbackData.fromJson(dynamic json)

Properties

acsCreq String?
getter/setter pair
acsUrl String?
getter/setter pair
cardToken String?
getter/setter pair
customerId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isAlreadyToken bool?
getter/setter pair
onepayTransactionId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited