Cards class

Constructors

Cards({String? tokenId, String? cardMask, String? cardExpire, String? cardType})
Cards.fromJson(dynamic json)

Properties

cardExpire String?
getter/setter pair
cardMask String?
getter/setter pair
cardType String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited