ThreeDSStatusData class

Constructors

ThreeDSStatusData({bool? isLoading, String? updateDatetime, bool? isPay, bool? isAuthenticate, bool? isAuthenticateStart})
ThreeDSStatusData.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
isAuthenticate bool?
getter/setter pair
isAuthenticateStart bool?
getter/setter pair
isLoading bool?
getter/setter pair
isPay bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateDatetime String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited