AuthHttpClient class

Constructors

AuthHttpClient()
factory
AuthHttpClient.internal()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String url, String appToken, {Map<String, String>? headers}) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String url, String appToken, {Map<String, String>? headers, Object? body}) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited