CustomerRepository class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createCustomerToken(
CreateCustomerTokenRequest payload, String appToken) → Future< CreateCustomerTokenResponse> -
get3DSStatus(
String token, String appToken) → Future< ThreeDSStatusResponse> -
getCustomers(
String appToken) → Future< CustomerListResponse> -
makeCustomerPayment(
CustomerPaymentRequest payload, String appToken) → Future< CustomerPaymentResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited