AppStrings class

Constructors

AppStrings()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

addCard → const String
addNewCard → const String
cardNumber → const String
cardNumberHint → const String
cvv → const String
cvvHint → const String
expireDate → const String
expireDateHint → const String
nameOnCard → const String
nameOnCardHint → const String
packageName → const String
securedBySpemai → const String
threeDSCheck → const String