RSAEncryptionHelper class

Constructors

RSAEncryptionHelper({required String publicKeyPem, String? privateKeyPem})

Properties

hashCode int
The hash code for this object.
no setterinherited
privateKey → RSAPrivateKey?
final
publicKey → RSAPublicKey
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(String base64Encrypted) Map<String, dynamic>
encrypt(Map<String, String> data) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited