ThreeDSBloc class
Constructors
Properties
-
check3DSStatusSink
→ StreamSink<
Response< ThreeDSStatusData> > -
no setter
-
check3DSStatusStream
→ Stream<
Response< ThreeDSStatusData> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkStatus(
String cardToken, String appToken) → dynamic -
dispose(
) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited