IPGBloc class
Constructors
- IPGBloc()
Properties
-
customerListSink
→ StreamSink<
Response< List< >Customer> > -
no setter
-
customerListStream
→ Stream<
Response< List< >Customer> > -
no setter
-
customerPaymentResponseSink
→ StreamSink<
Response< CustomerPaymentData> > -
no setter
-
customerPaymentResponseStream
→ Stream<
Response< CustomerPaymentData> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → dynamic -
getCustomers(
String appToken) → dynamic -
makeCustomerPayment(
String amount, String currency, String customerCardToken, String appId, String appToken) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited